Quantity classes
****************

.. currentmodule:: genno.core.attrseries

.. autoclass:: AttrSeries
   :members:

   .. py:attribute:: name

      The name of this Quantity.

      Like :attr:`.xarray.DataArray.name`.

.. automodule:: genno.core.attrseries
   :members:
   :exclude-members: AttrSeries

.. currentmodule:: genno.core.sparsedataarray

.. automodule:: genno.core.sparsedataarray
   :members: SparseDataArray, SparseAccessor

.. currentmodule:: genno.core.base

.. automodule:: genno.core.base
   :members:

.. currentmodule:: genno.core.quantity

.. automodule:: genno.core.quantity
   :members:
   :exclude-members: assert_quantity, get_class, set_class

.. currentmodule:: genno.compat.xarray

.. autoclass:: DataArrayLike
